==> 0.1.1.tar.gz: example/listview_demo.dart <==
import 'package:yflutter_widgets/widgets/listview/ylistview.dart';
import 'package:flutter/material.dart';

class ListViewDemo extends StatefulWidget {
  @override
  _ListViewDemoState createState() => _ListViewDemoState();
}

class _ListViewDemoState extends State<ListViewDemo> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      // appBar: AppBar(
      //   title: Text("ListView Demo"),
      //   // elevation: 0,
      //   // backgroundColor: Colors.transparent,
      // ),
      body: YListView(
        type: HeaderType.AppBar,
        title: "ListView Demo",
        titleColor: Colors.transparent,
        contractedTitleColor: Colors.black,
        headerColor: Colors.white,
        elevation: 8,
        leftBarItem: BackButton(color: Colors.yellow,),
        isForcedElevated: true,
        borderType: BorderType.None,
        listHeader: Container(color: Colors.blue, child: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            Padding(
              padding: EdgeInsets.only(bottom: 20+sOffset),
              child: Text("你好啊"),
            ),
          ],
        ),),
        headerHeight: 120,
        numOfSection: _sectionCount,
        numberOfRowsInSection: _numberOfRowsInSection,
        sectionHeight: _sectionHeight,
        cellHeight: _cellHeight,
        sectionHeader: _headerOfSectionAtIndex,
        cell: _cellOfRowAtIndex,
        contractedCallback: (isContracted){

        },
        scrollCallback: (offset){
          print("$offset");
          setState(() {
            sOffset = offset;
          });
        },
      ),
    );
  }

  double sOffset = 0.0;

  int _sectionCount = 3;

  int _numberOfRowsInSection(int sectionIndex) {
    if (sectionIndex == 0) {
      return 5;
    } else if (sectionIndex == 1) {
      return 10;
    } else {
      return 20;
    }
  }

  Widget _headerOfSectionAtIndex(BuildContext context, int sectionIndex) {
    return InkWell(
      onTap: () {
        print('click section header. -> section:$sectionIndex');
      },
      child: Container(
        alignment: Alignment.centerLeft,
        padding: EdgeInsets.only(left: 16.0),
        height: 100,
        child: Text('I am section header -> section:$sectionIndex'),
      ),
    );
  }

  Widget _cellOfRowAtIndex(BuildContext context, int sectionIndex, int rowIndex) {
    return InkWell(
      onTap: () {
        print('click cell item. -> section:$sectionIndex row:$rowIndex');
      },
      child: Container(
        padding: EdgeInsets.only(left: 16.0),
        alignment: Alignment.centerLeft,
        decoration: BoxDecoration(
            border: Border(
                bottom: BorderSide(
                  color: Color.fromRGBO(240, 240, 240, 1),
                ))),
        height: 50.0,
        child: Text('I am cell -> section:$sectionIndex  row$rowIndex'),
      ),
    );
  }

  double _sectionHeight(BuildContext context, int sectionIndex) {
    return 50.0;
  }

  double _cellHeight(BuildContext context, int section, int rowIndex) {
    return 50.0;
  }
}

==> 0.2.0.tar.gz: example/listview_demo.dart <==
import 'package:yflutter_widgets/widgets/listview/ylistview.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';

class ListViewDemo extends StatefulWidget {
  @override
  _ListViewDemoState createState() => _ListViewDemoState();
}

class _ListViewDemoState extends State<ListViewDemo> {
  EasyRefreshController _controller = EasyRefreshController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      // appBar: AppBar(
      //   title: Text("ListView Demo"),
      //   // elevation: 0,
      //   // backgroundColor: Colors.transparent,
      // ),
      body: YListView(
        type: HeaderType.AppBar,
        title: "ListView Demo",
        titleColor: Colors.transparent,
        contractedTitleColor: Colors.black,
        headerColor: Colors.white,
        elevation: 8,
        leftBarItem: BackButton(color: Colors.yellow,),
        isForcedElevated: true,
        borderType: BorderType.ListSection,
        listHeader: Container(color: Colors.blue, child: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            Padding(
              padding: EdgeInsets.only(bottom: 20+sOffset),
              child: Text("你好啊"),
            ),
          ],
        ),),
        headerHeight: 120,
        numOfSection: _sectionCount,
        numberOfRowsInSection: _numberOfRowsInSection,
        sectionHeight: _sectionHeight,
        cellHeight: _cellHeight,
        sectionHeader: _headerOfSectionAtIndex,
        cell: _cellOfRowAtIndex,
        hasRefresh: true,
        refreshCallback: () async {
          await Future.delayed(Duration(seconds: 2), () {
            if (mounted) {
              _controller.finishRefresh();
            }
          });
        },
        loadCallback: () async {
          await Future.delayed(Duration(seconds: 2), () {
            if (mounted) {
              _controller.finishLoad();
            }
          });
        },
        refreshController: _controller,
        contractedCallback: (isContracted){

        },
        scrollCallback: (offset){
          print("$offset");
          setState(() {
            sOffset = offset;
          });
        },
      ),
    );
  }

  double sOffset = 0.0;

  int _sectionCount = 3;

  int _numberOfRowsInSection(int sectionIndex) {
    if (sectionIndex == 0) {
      return 5;
    } else if (sectionIndex == 1) {
      return 10;
    } else {
      return 20;
    }
  }

  Widget _headerOfSectionAtIndex(BuildContext context, int sectionIndex) {
    return InkWell(
      onTap: () {
        print('click section header. -> section:$sectionIndex');
      },
      child: Container(
        alignment: Alignment.centerLeft,
        padding: EdgeInsets.only(left: 16.0),
        height: 100,
        child: Text('I am section header -> section:$sectionIndex'),
      ),
    );
  }

  Widget _cellOfRowAtIndex(BuildContext context, int sectionIndex, int rowIndex) {
    return InkWell(
      onTap: () {
        print('click cell item. -> section:$sectionIndex row:$rowIndex');
      },
      child: Container(
        padding: EdgeInsets.only(left: 16.0),
        alignment: Alignment.centerLeft,
        decoration: BoxDecoration(
            border: Border(
                bottom: BorderSide(
                  color: Color.fromRGBO(240, 240, 240, 1),
                ))),
        height: 50.0,
        child: Text('I am cell -> section:$sectionIndex  row$rowIndex'),
      ),
    );
  }

  double _sectionHeight(BuildContext context, int sectionIndex) {
    return 50.0;
  }

  double _cellHeight(BuildContext context, int section, int rowIndex) {
    return 50.0;
  }
}
